pub struct MatrixNormal { /* private fields */ }Expand description
Matrix normal distribution over real matrices.
Implementations
Sourceimpl MatrixNormal
impl MatrixNormal
Sourcepub fn new(
mean: DMatrix<f64>,
row_cov: DMatrix<f64>,
col_cov: DMatrix<f64>,
) -> Result<MatrixNormal, String>
pub fn new( mean: DMatrix<f64>, row_cov: DMatrix<f64>, col_cov: DMatrix<f64>, ) -> Result<MatrixNormal, String>
Construct a matrix normal distribution with mean matrix mean, row
covariance row_cov, and column covariance col_cov.
Errors
Returns Err if covariance dimensions do not match the mean or either
covariance is not symmetric positive-definite.